def _load_json(file_path):
    import json
    import pkg_resources

    ifile = pkg_resources.resource_stream(__name__, file_path)
    d = json.load(ifile)
    return d


CURVE_TRICRYPTO_ABI = _load_json("json/Curve_tricrypto.json")
CURVE_TRICRYPTO_MATH_ABI = _load_json("json/Curve_tricrypto_math.json")
CURVE_TRICRYPTO_VIEW_ABI = _load_json("json/Curve_tricrypto_view.json")
CURVE_3COIN_POOL_ABI = _load_json("json/Curve_3coin_pool.json")



def _load_json(file_path):
    import json
    import pkg_resources

    ifile = pkg_resources.resource_stream(__name__, file_path)
    d = json.load(ifile)
    return d


BALANCER_V2_VAULT_ABI = _load_json("json/Vault.json")
BALANCER_V2_WEIGHTED_POOL_ABI = _load_json("json/WeightedPool.json")
BALANCER_V2_WEIGHTED_POOL_2TOKENS_ABI = _load_json("json/WeightedPool2Tokens.json")

BEETHOVENX_VAULT_ABI = BALANCER_V2_VAULT_ABI
BEETHOVENX_WEIGHTED_POOL_ABI = BALANCER_V2_WEIGHTED_POOL_ABI
BEETHOVENX_WEIGHTED_POOL_2TOKENS_ABI = BALANCER_V2_WEIGHTED_POOL_2TOKENS_ABI



def _load_json(file_path):
    import json
    import pkg_resources

    ifile = pkg_resources.resource_stream(__name__, file_path)
    d = json.load(ifile)
    return d


UNISWAP_V2_PAIR_ABI = _load_json("json/UniswapV2Pair.json")
UNISWAP_V2_ROUTER_ABI = _load_json("json/UniswapV2Router.json")
UNISWAP_V2_FACTORY_ABI = _load_json("json/UniswapV2Factory.json")

SPOOKY_SWAP_ROUTER_ABI = UNISWAP_V2_ROUTER_ABI
SPOOKY_SWAP_FACTORY_ABI = UNISWAP_V2_FACTORY_ABI
SPOOKY_SWAP_PAIR_ABI = UNISWAP_V2_PAIR_ABI
